

set -ex



test -L $PREFIX/lib/libnvToolsExt.so.1
test -L $PREFIX/lib/libnvToolsExt.so.1.0.0
test -L $PREFIX/targets/sbsa-linux/lib/libnvToolsExt.so.1
test -f $PREFIX/targets/sbsa-linux/lib/libnvToolsExt.so.1.0.0
exit 0
